/* global angular, document, window */
'use strict';

var app = angular.module('starter.controllers', [])

app.controller('AppCtrl', function ($scope, $ionicModal, $ionicPopover, $timeout) {
    // Form data for the login modal
    $scope.loginData = {};
    $scope.isExpanded = false;
    $scope.hasHeaderFabLeft = false;
    $scope.hasHeaderFabRight = false;

    var navIcons = document.getElementsByClassName('ion-navicon');
    for (var i = 0; i < navIcons.length; i++) {
        navIcons.addEventListener('click', function () {
            this.classList.toggle('active');
        });
    }

    ////////////////////////////////////////
    // Layout Methods
    ////////////////////////////////////////

    $scope.hideNavBar = function () {
        document.getElementsByTagName('ion-nav-bar')[0].style.display = 'none';
    };

    $scope.showNavBar = function () {
        document.getElementsByTagName('ion-nav-bar')[0].style.display = 'block';
    };

    $scope.noHeader = function () {
        var content = document.getElementsByTagName('ion-content');
        for (var i = 0; i < content.length; i++) {
            if (content[i].classList.contains('has-header')) {
                content[i].classList.toggle('has-header');
            }
        }
    };

    $scope.setExpanded = function (bool) {
        $scope.isExpanded = bool;
    };

    $scope.setHeaderFab = function (location) {
        var hasHeaderFabLeft = false;
        var hasHeaderFabRight = false;

        switch (location) {
        case 'left':
            hasHeaderFabLeft = true;
            break;
        case 'right':
            hasHeaderFabRight = true;
            break;
        }

        $scope.hasHeaderFabLeft = hasHeaderFabLeft;
        $scope.hasHeaderFabRight = hasHeaderFabRight;
    };

    $scope.hasHeader = function () {
        var content = document.getElementsByTagName('ion-content');
        for (var i = 0; i < content.length; i++) {
            if (!content[i].classList.contains('has-header')) {
                content[i].classList.toggle('has-header');
            }
        }

    };

    $scope.hideHeader = function () {
        $scope.hideNavBar();
        $scope.noHeader();
    };

    $scope.showHeader = function () {
        $scope.showNavBar();
        $scope.hasHeader();
    };

    $scope.clearFabs = function () {
        var fabs = document.getElementsByClassName('button-fab');
        if (fabs.length && fabs.length > 1) {
            fabs[0].remove();
        }
    };
})

app.controller('AuthCtrl', function ($scope, $state) {
    if (localStorage.auth) {
        $state.go("app.profile");
    } else {
        $state.go("login");
    }
})

app.controller('LoginCtrl', function ($scope, $state, $ionicPlatform, $timeout, $stateParams, $ionicLoading, ionicMaterialInk, $ionicHistory, auth) {
    $scope.auth = {};

    $ionicPlatform.registerBackButtonAction(function (event) {
        event.preventDefault();
        event.stopPropagation();
        navigator.app.exitApp();
    }, 100);


    $scope.login = function () {
        $ionicLoading.show();
        auth.advisorLogin($scope.auth).success(function (response) {
            if (response.status) {
                alert(response.message);
            } else {
                localStorage.auth = JSON.stringify($scope.auth);
                localStorage.profile = JSON.stringify(response.data);
                $state.go("app.home");
            }
        }).finally(function () {
            $ionicLoading.hide();
        });
    }
    ionicMaterialInk.displayEffect();
})
app.controller('LogoutCtrl', function ($scope, $state, $timeout, $stateParams, ionicMaterialInk, auth) {
    $scope.auth = {};
    delete localStorage.auth;
    $state.go("login");
    ionicMaterialInk.displayEffect();
})
app.controller('HomeCtrl', function ($scope, $timeout, $ionicPlatform, $ionicPopup, ionicMaterialMotion, ionicMaterialInk) {
    // Set Header
    $scope.$parent.showHeader();
    $scope.$parent.clearFabs();
    $scope.isExpanded = false;
    $scope.$parent.setExpanded(false);
    $scope.$parent.setHeaderFab(false);

    $ionicPlatform.registerBackButtonAction(function (event) {
        event.preventDefault();
        event.stopPropagation();
        
        var confirmPopup = $ionicPopup.confirm({
            title: 'Alert',
            template: 'Press ok to exit.'
        });
        confirmPopup.then(function (res) {
            if (res) {
                navigator.app.exitApp();
            }
        });
        confirmPopup();
    }, 100);

    $scope.profile = JSON.parse(localStorage.profile);
    // Set Motion
    $timeout(function () {
        ionicMaterialMotion.slideUp({
            selector: '.slide-up'
        });
    }, 300);

    $timeout(function () {
        ionicMaterialMotion.fadeSlideInRight({
            startVelocity: 3000
        });
    }, 700);

    // Set Ink
    ionicMaterialInk.displayEffect();
})
app.controller('ProfileCtrl', function ($scope, $stateParams, $timeout, $ionicModal, advisor, ionicMaterialMotion, ionicMaterialInk) {
    // Set Header
    $scope.$parent.showHeader();
    $scope.$parent.clearFabs();
    $scope.isExpanded = false;
    $scope.$parent.setExpanded(false);
    $scope.$parent.setHeaderFab(false);

    $scope.profile = JSON.parse(localStorage.profile);
    $scope.update = {
        id: $scope.profile.id,
        contact: {
            email: $scope.profile.contact.email,
            mobile: $scope.profile.contact.mobile
        }
    };
    // Set Motion
    $timeout(function () {
        ionicMaterialMotion.slideUp({
            selector: '.slide-up'
        });
    }, 300);

    $timeout(function () {
        ionicMaterialMotion.fadeSlideInRight({
            startVelocity: 3000
        });
    }, 700);

    //model
    $ionicModal.fromTemplateUrl('my-modal.html', {
        scope: $scope,
        animation: 'slide-in-up'
    }).then(function (modal) {
        $scope.modal = modal;
    });
    $scope.openModal = function () {
        console.log($scope.update);
        $scope.modal.show();
    };
    $scope.closeModal = function () {
        $scope.modal.hide();
    };
    $scope.action = function () {
        advisor.update($scope.update).success(function (response) {
            $scope.profile.contact.mobile = response.data.mobile;
            $scope.profile.contact.email = response.data.email;
            localStorage.profile = JSON.stringify($scope.profile);
            $scope.closeModal();
        }).error(function (error) {
            alert(error.message);
        })
    };

    // Set Ink
    ionicMaterialInk.displayEffect();
})
app.controller('MonthlyComissionCtrl', function ($scope, $stateParams, $timeout, ionicMaterialMotion, ionicMaterialInk, advisor) {
    // Set Header
    $scope.$parent.showHeader();
    $scope.$parent.clearFabs();
    $scope.isExpanded = false;
    $scope.$parent.setExpanded(false);
    $scope.$parent.setHeaderFab(false);

    $scope.comission = {};
    var a = JSON.parse(localStorage.profile);
    $scope.init = function () {
        advisor.comission(a.id).success(function (response) {
            $scope.comission = response.data;
        }).error(function (error) {
            alert(error.message);
        })
    };
    // Set Motion
    $timeout(function () {
        ionicMaterialMotion.slideUp({
            selector: '.slide-up'
        });
    }, 300);

    $timeout(function () {
        ionicMaterialMotion.fadeSlideInRight({
            startVelocity: 3000
        });
    }, 700);

    $scope.init();
    // Set Ink
    ionicMaterialInk.displayEffect();
})
app.controller('VoucherCtrl', function ($scope, $stateParams, $timeout, ionicMaterialMotion, ionicMaterialInk, advisor) {
    // Set Header
    $scope.$parent.showHeader();
    $scope.$parent.clearFabs();
    $scope.isExpanded = false;
    $scope.$parent.setExpanded(false);
    $scope.$parent.setHeaderFab(false);

    $scope.vouchers = {};
    var a = JSON.parse(localStorage.profile);
    $scope.init = function () {
        advisor.voucher(a.id).success(function (response) {
            $scope.vouchers = response.data;
        }).error(function (error) {
            alert(error.message);
        })
    };
    // Set Motion
    $timeout(function () {
        ionicMaterialMotion.slideUp({
            selector: '.slide-up'
        });
    }, 300);

    $timeout(function () {
        ionicMaterialMotion.fadeSlideInRight({
            startVelocity: 3000
        });
    }, 700);

    $scope.init();
    // Set Ink
    ionicMaterialInk.displayEffect();
})
app.controller('PaymentCtrl', function ($scope, $stateParams, $timeout, ionicMaterialMotion, ionicMaterialInk, advisor) {
    // Set Header
    $scope.$parent.showHeader();
    $scope.$parent.clearFabs();
    $scope.isExpanded = false;
    $scope.$parent.setExpanded(false);
    $scope.$parent.setHeaderFab(false);

    $scope.payments = {};
    var a = JSON.parse(localStorage.profile);
    $scope.init = function () {
        advisor.payment(a.id).success(function (response) {
            $scope.payments = response.data;
        }).error(function (error) {
            alert(error.message);
        })
    };
    // Set Motion
    $timeout(function () {
        ionicMaterialMotion.slideUp({
            selector: '.slide-up'
        });
    }, 300);

    $timeout(function () {
        ionicMaterialMotion.fadeSlideInRight({
            startVelocity: 3000
        });
    }, 700);

    $scope.init();
    // Set Ink
    ionicMaterialInk.displayEffect();
})
app.controller('ChainListCtrl', function ($scope, $stateParams, $timeout, $ionicLoading, ionicMaterialMotion, ionicMaterialInk, advisor) {
    // Set Header
    $scope.$parent.showHeader();
    $scope.$parent.clearFabs();
    $scope.isExpanded = false;
    $scope.$parent.setExpanded(false);
    $scope.$parent.setHeaderFab(false);

    $scope.chainlist = {};
    var a = JSON.parse(localStorage.profile);
    $scope.init = function () {
        $ionicLoading.show();
        advisor.chainlist(a.id).success(function (response) {
            $scope.chainlist = response.data;
        }).error(function (error) {
            alert(error.message);
        }).finally(function () {
            $ionicLoading.hide();
        })
    };
    // Set Motion
    $timeout(function () {
        ionicMaterialMotion.slideUp({
            selector: '.slide-up'
        });
    }, 300);

    $timeout(function () {
        ionicMaterialMotion.fadeSlideInRight({
            startVelocity: 3000
        });
    }, 700);

    $scope.init();
    // Set Ink
    ionicMaterialInk.displayEffect();
})
app.controller('DirectMemberCtrl', function ($scope, $stateParams, $timeout, ionicMaterialMotion, ionicMaterialInk, advisor) {
    // Set Header
    $scope.$parent.showHeader();
    $scope.$parent.clearFabs();
    $scope.isExpanded = false;
    $scope.$parent.setExpanded(false);
    $scope.$parent.setHeaderFab(false);

    $scope.directmember = {};
    var a = JSON.parse(localStorage.profile);
    $scope.init = function () {
        advisor.directmember(a.id).success(function (response) {
            $scope.directmember = response.data;
        }).error(function (error) {
            alert(error.message);
        })
    };
    // Set Motion
    $timeout(function () {
        ionicMaterialMotion.slideUp({
            selector: '.slide-up'
        });
    }, 300);

    $timeout(function () {
        ionicMaterialMotion.fadeSlideInRight({
            startVelocity: 3000
        });
    }, 700);

    $scope.init();
    // Set Ink
    ionicMaterialInk.displayEffect();
})
app.controller('NotificationCtrl', function ($scope, $stateParams, $timeout, ionicMaterialMotion, ionicMaterialInk, advisor) {
    // Set Header
    $scope.$parent.showHeader();
    $scope.$parent.clearFabs();
    $scope.isExpanded = false;
    $scope.$parent.setExpanded(false);
    $scope.$parent.setHeaderFab(false);

    $scope.notifications = {};
    var a = JSON.parse(localStorage.profile);
    $scope.init = function () {
        advisor.notifications(a.id).success(function (response) {
            $scope.notifications = response.data;
        }).error(function (error) {
            alert(error.message);
        })
    };
    // Set Motion
    $timeout(function () {
        ionicMaterialMotion.slideUp({
            selector: '.slide-up'
        });
    }, 300);

    $timeout(function () {
        ionicMaterialMotion.fadeSlideInRight({
            startVelocity: 3000
        });
    }, 700);

    $scope.init();
    // Set Ink
    ionicMaterialInk.displayEffect();
})
app.controller('CalenderCtrl', function ($scope, $stateParams, $timeout, ionicMaterialMotion, ionicMaterialInk, advisor) {
    // Set Header
    $scope.$parent.showHeader();
    $scope.$parent.clearFabs();
    $scope.isExpanded = false;
    $scope.$parent.setExpanded(false);
    $scope.$parent.setHeaderFab(false);

    $scope.calender = {};
    var d = new Date();
    var n = d.getFullYear();
    $scope.init = function () {
        advisor.calender(n).success(function (response) {
            $scope.calender = response.data;
        }).error(function (error) {
            alert(error.message);
        })
    };
    // Set Motion
    $timeout(function () {
        ionicMaterialMotion.slideUp({
            selector: '.slide-up'
        });
    }, 300);

    $timeout(function () {
        ionicMaterialMotion.fadeSlideInRight({
            startVelocity: 3000
        });
    }, 700);

    $scope.init();
    // Set Ink
    ionicMaterialInk.displayEffect();
})